@@ -242,7 +242,11 @@ class DagBuilder:
         dag: DAG = DAG(
             dag_id=dag_params["dag_id"],
             schedule_interval=dag_params.get("schedule_interval", timedelta(days=1)),
-            description=dag_params.get("description", None),
+            description=(
+                dag_params.get("description", None)
+                if version.parse(AIRFLOW_VERSION) >= version.parse("1.10.11")
+                else dag_params.get("description", "")
+            ),
             concurrency=dag_params.get(
                 "concurrency",
                 configuration.conf.getint("core", "dag_concurrency"),
